# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
#     http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.
from awscli.testutils import BaseAWSCommandParamsTest


class TestUpdateStack(BaseAWSCommandParamsTest):
    prefix = 'cloudformation update-stack'

    def test_stack_policy_during_update_url(self):
        cmdline = self.prefix
        cmdline += ' --stack-name test-stack '
        cmdline += '--stack-policy-during-update-url http://foo'
        result = {
            'StackName': 'test-stack',
            'StackPolicyDuringUpdateURL': 'http://foo',
        }
        self.assert_params_for_cmd(cmdline, result)
